@@ -121,7 +121,7 @@ class MySqlRepository(DBRepository[T, DBConfiguration]):
         limit: int = 500, offset: int = 0) -> List[T]:
 
         fields = '*' if not fields else ', '.join(fields)
-        clauses = list(filters.values) if filters else None
+        clauses = list(filter(None, filters.values)) if filters else None
         orders = list(filter(None, order_bys)) if order_bys else None
         sql = f"SELECT {fields} FROM {self.table_name()} " \
               f"{('WHERE ' + ' AND '.join(clauses)) if clauses else ''} " \
